@@ -2,6 +2,7 @@ import os
 
 import click as click
 import pkg_resources
+from click_option_group import optgroup
 
 from notifier.gpu_monitor import run_monitoring
 from notifier.telegram import TelegramNotifier
@@ -21,7 +22,8 @@ def get_telegram_notifier() -> TelegramNotifier:
 
 
 @click.group()
-def cli():
+@click.option('--version')
+def cli(version):
     pass
 
 
